pub struct AcceptFlags { /* private fields */ }Implementations
Sourceimpl AcceptFlags
impl AcceptFlags
Sourcepub fn empty() -> AcceptFlags
pub fn empty() -> AcceptFlags
Returns an empty set of flags.
Sourcepub fn all() -> AcceptFlags
pub fn all() -> AcceptFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: c_int) -> Option<AcceptFlags>
pub fn from_bits(bits: c_int) -> Option<AcceptFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: c_int) -> AcceptFlags
pub fn from_bits_truncate(bits: c_int) -> AcceptFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: AcceptFlags) -> bool
pub fn intersects(&self, other: AcceptFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: AcceptFlags) -> bool
pub fn contains(&self, other: AcceptFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: AcceptFlags)
pub fn insert(&mut self, other: AcceptFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: AcceptFlags)
pub fn remove(&mut self, other: AcceptFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: AcceptFlags)
pub fn toggle(&mut self, other: AcceptFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: AcceptFlags, value: bool)
pub fn set(&mut self, other: AcceptFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.